@@ -1049,7 +1049,7 @@ def test_by_module_statement_value(initialized_linter: PyLinter) -> None:
 
 def test_finds_pyi_file() -> None:
     run = Run(
-        [join(REGRTEST_DATA_DIR, "pyi")],
+        ["--prefer-stubs=y", join(REGRTEST_DATA_DIR, "pyi")],
         exit=False,
     )
     assert run.linter.current_file is not None
@@ -1061,6 +1061,8 @@ def test_recursive_finds_pyi_file() -> None:
         [
             "--recursive",
             "y",
+            "--prefer-stubs",
+            "y",
             join(REGRTEST_DATA_DIR, "pyi"),
         ],
         exit=False,
@@ -1069,6 +1071,20 @@ def test_recursive_finds_pyi_file() -> None:
     assert run.linter.current_file.endswith("foo.pyi")
 
 
+def test_no_false_positive_from_pyi_stub() -> None:
+    run = Run(
+        [
+            "--recursive",
+            "y",
+            "--prefer-stubs",
+            "n",
+            join(REGRTEST_DATA_DIR, "uses_module_with_stub.py"),
+        ],
+        exit=False,
+    )
+    assert not run.linter.stats.by_msg
+
+
 @pytest.mark.parametrize(
     "ignore_parameter,ignore_parameter_value",
     [
@@ -1171,7 +1187,7 @@ def test_globbing() -> None:
 
 
 def test_relative_imports(initialized_linter: PyLinter) -> None:
-    """Regression test for https://github.com/pylint-dev/pylint/issues/3651"""
+    """Regression test for https://github.com/pylint-dev/pylint/issues/3651."""
     linter = initialized_linter
     with tempdir() as tmpdir:
         create_files(["x/y/__init__.py", "x/y/one.py", "x/y/two.py"], tmpdir)
@@ -1204,7 +1220,8 @@ TWO = ONE + ONE
 
 def test_import_sibling_module_from_namespace(initialized_linter: PyLinter) -> None:
     """If the parent directory above `namespace` is on sys.path, ensure that
-    modules under `namespace` can import each other without raising `import-error`."""
+    modules under `namespace` can import each other without raising `import-error`.
+    """
     linter = initialized_linter
     with tempdir() as tmpdir:
         create_files(["namespace/submodule1.py", "namespace/submodule2.py"])
@@ -1226,7 +1243,7 @@ print(submodule1)
 
 
 def test_lint_namespace_package_under_dir(initialized_linter: PyLinter) -> None:
-    """Regression test for https://github.com/pylint-dev/pylint/issues/1667"""
+    """Regression test for https://github.com/pylint-dev/pylint/issues/1667."""
     linter = initialized_linter
     with tempdir():
         create_files(["outer/namespace/__init__.py", "outer/namespace/module.py"])
@@ -1236,7 +1253,8 @@ def test_lint_namespace_package_under_dir(initialized_linter: PyLinter) -> None:
 
 def test_lint_namespace_package_under_dir_on_path(initialized_linter: PyLinter) -> None:
     """If the directory above a namespace package is on sys.path,
-    the namespace module under it is linted."""
+    the namespace module under it is linted.
+    """
     linter = initialized_linter
     with tempdir() as tmpdir:
         create_files(["namespace_on_path/submodule1.py"])
